Presets and pipeline — ADA 1.0.3 documentation

Skip to main content
`Ctrl`+`K`

# Presets and pipeline

## Presets

Presets enable one-click analysis and visualization of actigraphic data.

By default, each preset uses the Activity Index epocher (for details see `ActivityIndex`).

The following predefined presets are available in ADA GUI. Algorithm names are links to the API reference:

1. Cole Kripke — Activity Index (ActivityIndex) into 60 s epochs + Cole–Kripke sleep/wake scoring (for details see `ColeKripke`)

2. Unified Filter 60 — Activity Index (ActivityIndex) into 60 s epochs + UFA scoring (for details see `UFA`)

3. Unified Filter 30 — Activity Index (ActivityIndex) into 30 s epochs + UFA scoring (for details see `UFA`)

4. Simple Nonparametric — Activity Index (ActivityIndex) into 60 s epochs + nonparametric circadian metrics (IS, IV, M10, L5) (for details see `SimpleNonparametric`)

5. Cosinor Linear — Activity Index (ActivityIndex) into 60 s epochs + linear or nonlinear cosinor (24 h period) (for details see `Nonlinear`)

6. Cosinor Hill — Activity Index (ActivityIndex) into 60 s epochs + Hill-transformed cosinor (for details see `Hill`)

7. DFA — Activity Index (ActivityIndex) into 60 s epochs + detrended fluctuation analysis (for details see `DFA`)

8. AR — Activity Index (ActivityIndex) into 10-minute epochs + autoregressive spectral analysis (for details see `AR`)

## Pipeline

1. Collapsing into epochs

The following epoching algorithms are available in ADA GUI. Explanaiton of their particular parameters can be found in API reference:

1. Activity Index — `ActivityIndex`

2. MIMS — `MIMS`

3. Mean Vector Magnitude (ENMO) — `MVM`

4. Standard downsampling — `Downsampler`

The Show advanced checkbox in the GUI allows users to view algorithm-specific parameters, including:

1. Modify the daily profile smoothing window length

2. Enable or disable normalization

3. Change stationary variance values (which are automatically detected if checkbox is enabled)

2. Sleep/wake scoring

The following scoring algorithms are available in ADA GUI. Explanaiton of their particular parameters can be found in API reference:

1. Cole–Kripke — `ColeKripke`

2. UCSD — `UCSD`

3. Unified Filter — `UFA`

4. Scripps — `Scripps`

5. Sazonov — `Sazonov`

6. Webster — `Webster`

The Show advanced checkbox in the GUI allows users to adjust threshold parameters. If the checkbox is checked, threshold will be selected automatically by ADA (if available.) Otherwise, you must set its value manually.

3. Circadian rhythms

The following parametric and nonparametric methods are available in ADA GUI. Explanaiton of their particular parameters can be found in API reference:

1. Linear cosinor (single- and multicomponent) — `Linear`

2. Nonlinear cosinor (single- and multicomponent) — `Nonlinear`

3. Hill-transformed cosinor — `Hill`

4. Arctangent-transformed cosinor — `Arctangent`

5. Antilogistically transformed cosinor — `Antilogistic`

6. Detrended fluctuation analysis — `DFA`

7. Autoregressive mode — `Spectrum`

8. Simple nonparametric estimators (IS, IV, M10, L5) — `SimpleNonparametric`

The Show advanced checkbox in the GUI allows users to set algorithm-specific parameters, e.g.:

1. Set period range for cosinor variants

2. Enable preprocessing, which may influence the period fit

3. Apply bootstrap validation (estimating statistical significance of cosinor model via bootstrap, or confidence interval for period in case of AR model)

4. Set DFA parameters, e.g. range of window lenghts and their number